@@ -1,12 +1,12 @@
 use std::str::FromStr;
 
-use anyhow::{bail, format_err, Error};
+use anyhow::{Error, bail, format_err};
 use regex::Regex;
 use serde_derive::Serialize;
 
 use crate::url::Url;
 
-#[derive(Debug, PartialEq, Eq, Hash, Serialize, Clone)]
+#[derive(Debug, PartialEq, Eq, Hash, Serialize, Clone, Copy)]
 pub enum EnumeratedListType {
     Arabic,
     LowerAlpha,
@@ -15,7 +15,25 @@ pub enum EnumeratedListType {
     UpperRoman,
 }
 
-#[derive(Default, Debug, PartialEq, Eq, Hash, Serialize, Clone)]
+#[derive(Debug, PartialEq, Eq, Hash, Serialize, Clone, Copy)]
+pub enum AutoFootnoteType {
+    Number,
+    Symbol,
+}
+
+impl TryFrom<char> for AutoFootnoteType {
+    type Error = ();
+
+    fn try_from(c: char) -> Result<Self, Self::Error> {
+        match c {
+            '#' => Ok(AutoFootnoteType::Number),
+            '*' => Ok(AutoFootnoteType::Symbol),
+            _ => Err(()),
+        }
+    }
+}
+
+#[derive(Default, Debug, PartialEq, Eq, Hash, Serialize, Clone, Copy)]
 pub enum FixedSpace {
     Default,
     // yes, default really is not “Default”
@@ -23,13 +41,13 @@ pub enum FixedSpace {
     Preserve,
 }
 
-#[derive(Debug, PartialEq, Eq, Hash, Serialize, Clone)]
+#[derive(Debug, PartialEq, Eq, Hash, Serialize, Clone, Copy)]
 pub enum AlignH {
     Left,
     Center,
     Right,
 }
-#[derive(Debug, PartialEq, Eq, Hash, Serialize, Clone)]
+#[derive(Debug, PartialEq, Eq, Hash, Serialize, Clone, Copy)]
 pub enum AlignHV {
     Top,
     Middle,
@@ -38,14 +56,14 @@ pub enum AlignHV {
     Center,
     Right,
 }
-#[derive(Debug, PartialEq, Eq, Hash, Serialize, Clone)]
+#[derive(Debug, PartialEq, Eq, Hash, Serialize, Clone, Copy)]
 pub enum AlignV {
     Top,
     Middle,
     Bottom,
 }
 
-#[derive(Debug, PartialEq, Eq, Hash, Serialize, Clone)]
+#[derive(Debug, PartialEq, Eq, Hash, Serialize, Clone, Copy)]
 pub enum TableAlignH {
     Left,
     Right,
@@ -53,7 +71,7 @@ pub enum TableAlignH {
     Justify,
     Char,
 }
-#[derive(Debug, PartialEq, Eq, Hash, Serialize, Clone)]
+#[derive(Debug, PartialEq, Eq, Hash, Serialize, Clone, Copy)]
 pub enum TableBorder {
     Top,
     Bottom,
@@ -77,7 +95,7 @@ pub struct TableGroupCols(pub usize);
 // no eq for f64
 #[derive(Debug, PartialEq, Serialize, Clone)]
 pub enum Measure {
-    // http://docutils.sourceforge.net/docs/ref/rst/restructuredtext.html#length-units
+    // https://docutils.sourceforge.net/docs/ref/rst/restructuredtext.html#length-units
     Em(f64),
     Ex(f64),
     Mm(f64),
@@ -91,14 +109,14 @@ pub enum Measure {
 impl FromStr for AlignHV {
     type Err = Error;
     fn from_str(s: &str) -> Result<Self, Self::Err> {
-        use self::AlignHV::*;
+        use self::AlignHV as A;
         Ok(match s {
-            "top" => Top,
-            "middle" => Middle,
-            "bottom" => Bottom,
-            "left" => Left,
-            "center" => Center,
-            "right" => Right,
+            "top" => A::Top,
+            "middle" => A::Middle,
+            "bottom" => A::Bottom,
+            "left" => A::Left,
+            "center" => A::Center,
+            "right" => A::Right,
             s => bail!("Invalid Alignment {}", s),
         })
     }
@@ -119,7 +137,7 @@ impl From<&str> for NameToken {
 impl FromStr for Measure {
     type Err = Error;
     fn from_str(s: &str) -> Result<Self, Self::Err> {
-        use self::Measure::*;
+        use self::Measure as M;
         let re =
             Regex::new(r"(?P<float>\d+\.\d*|\.?\d+)\s*(?P<unit>em|ex|mm|cm|in|px|pt|pc)").unwrap();
         let caps: regex::Captures = re
@@ -127,14 +145,14 @@ impl FromStr for Measure {
             .ok_or_else(|| format_err!("Invalid measure"))?;
         let value: f64 = caps["float"].parse()?;
         Ok(match &caps["unit"] {
-            "em" => Em(value),
-            "ex" => Ex(value),
-            "mm" => Mm(value),
-            "cm" => Cm(value),
-            "in" => In(value),
-            "px" => Px(value),
-            "pt" => Pt(value),
-            "pc" => Pc(value),
+            "em" => M::Em(value),
+            "ex" => M::Ex(value),
+            "mm" => M::Mm(value),
+            "cm" => M::Cm(value),
+            "in" => M::In(value),
+            "px" => M::Px(value),
+            "pt" => M::Pt(value),
+            "pc" => M::Pc(value),
             _ => unreachable!(),
         })
     }
