@@ -1,7 +1,8 @@
 use serde_derive::Serialize;
 use std::path::PathBuf;
 
-use crate::attribute_types::{CanBeEmpty, NameToken, ID};
+use crate::attribute_types::{CanBeEmpty, ID, NameToken};
+#[allow(clippy::wildcard_imports)]
 use crate::element_categories::*;
 use crate::extra_attributes::{self, ExtraAttributes};
 
@@ -132,6 +133,7 @@ macro_rules! impl_new {(
         $(#[$fattr])* $field: $typ,
     )* }
     impl $name {
+        #[must_use]
         pub fn new( $( $field: $typ, )* ) -> $name { $name { $( $field, )* } }
     }
 )}
@@ -347,3 +349,48 @@ impl<'a> From<&'a str> for TextOrInlineElement {
         s.to_owned().into()
     }
 }
+
+pub trait LabelledFootnote {
+    /// Get the footnote’s/footnote reference’s label node, if available
+    ///
+    /// # Errors
+    /// Returns an error if the footnote has no label
+    fn get_label(&self) -> Result<&str, anyhow::Error>;
+}
+
+impl LabelledFootnote for Footnote {
+    fn get_label(&self) -> Result<&str, anyhow::Error> {
+        use anyhow::{Context, bail};
+
+        let SubFootnote::Label(e) = self
+            .children()
+            .first()
+            .context("Footnote has no children")?
+        else {
+            bail!("Non-auto footnote has no label");
+        };
+        match e
+            .children()
+            .first()
+            .context("Footnote label has no child")?
+        {
+            TextOrInlineElement::String(s) => Ok(s.as_ref()),
+            _ => bail!("Footnote label is not a string"),
+        }
+    }
+}
+
+impl LabelledFootnote for FootnoteReference {
+    fn get_label(&self) -> Result<&str, anyhow::Error> {
+        use anyhow::{Context, bail};
+
+        match self
+            .children()
+            .first()
+            .context("Footnote reference has no child")?
+        {
+            TextOrInlineElement::String(s) => Ok(s.as_ref()),
+            _ => bail!("Footnote reference is not a string"),
+        }
+    }
+}
