@@ -1,9 +1,10 @@
 use serde_derive::Serialize;
 
 use crate::attribute_types::{
-    AlignH, AlignHV, AlignV, CanBeEmpty, EnumeratedListType, FixedSpace, Measure, NameToken,
-    TableAlignH, TableBorder, TableGroupCols, ID,
+    AlignH, AlignHV, AlignV, AutoFootnoteType, CanBeEmpty, EnumeratedListType, FixedSpace, ID,
+    Measure, NameToken, TableAlignH, TableBorder, TableGroupCols,
 };
+use crate::elements as e;
 use crate::url::Url;
 
 pub trait ExtraAttributes<A> {
@@ -63,7 +64,7 @@ impl_extra!(#[derive(Debug,PartialEq,Serialize,Clone)] Image {
 impl_extra!(BulletList { bullet: Option<String> });
 impl_extra!(EnumeratedList { enumtype: Option<EnumeratedListType>, prefix: Option<String>, suffix: Option<String> });
 
-impl_extra!(Footnote { backrefs: Vec<ID>, auto: bool });
+impl_extra!(Footnote { backrefs: Vec<ID>, auto: Option<AutoFootnoteType> });
 impl_extra!(Citation { backrefs: Vec<ID> });
 impl_extra!(SystemMessage { backrefs: Vec<ID>, level: Option<usize>, line: Option<usize>, type_: Option<NameToken> });
 impl_extra!(Figure { align: Option<AlignH>, width: Option<usize> });
@@ -87,7 +88,7 @@ impl_extra!(Reference {
     /// Internal reference to the names attribute of another element
     refname: Vec<NameToken>,
 });
-impl_extra!(FootnoteReference { refid: Option<ID>, refname: Vec<NameToken>, auto: bool });
+impl_extra!(FootnoteReference { refid: Option<ID>, refname: Vec<NameToken>, auto: Option<AutoFootnoteType> });
 impl_extra!(CitationReference { refid: Option<ID>, refname: Vec<NameToken> });
 impl_extra!(SubstitutionReference { refname: Vec<NameToken> });
 impl_extra!(Problematic { refid: Option<ID> });
@@ -105,7 +106,42 @@ impl_extra!(TargetInline {
 impl_extra!(RawInline { space: FixedSpace, format: Vec<NameToken> });
 pub type ImageInline = Image;
 
+pub trait FootnoteType {
+    /// Is this an auto-numbered footnote?
+    fn is_auto(&self) -> bool;
+    /// Is this a symbolic footnote and not a numeric one?
+    fn is_symbol(&self) -> bool;
+}
+
+impl FootnoteType for Option<AutoFootnoteType> {
+    fn is_auto(&self) -> bool {
+        self.is_some()
+    }
+    fn is_symbol(&self) -> bool {
+        matches!(self, Some(AutoFootnoteType::Symbol))
+    }
+}
+
+impl FootnoteType for e::Footnote {
+    fn is_auto(&self) -> bool {
+        self.extra().auto.is_auto()
+    }
+    fn is_symbol(&self) -> bool {
+        self.extra().auto.is_symbol()
+    }
+}
+
+impl FootnoteType for e::FootnoteReference {
+    fn is_auto(&self) -> bool {
+        self.extra().auto.is_auto()
+    }
+    fn is_symbol(&self) -> bool {
+        self.extra().auto.is_symbol()
+    }
+}
+
 impl Image {
+    #[must_use]
     pub fn new(uri: Url) -> Image {
         Image {
             uri,
