@@ -1,9 +1,10 @@
+#![warn(clippy::pedantic)]
 #![recursion_limit = "256"]
 
-/// See [doctree][] reference.
-/// Serves as AST.
-///
-/// [doctree]: http://docutils.sourceforge.net/docs/ref/doctree.html
+//! See [doctree][] reference.
+//! Serves as AST.
+//!
+//! [doctree]: https://docutils.sourceforge.net/docs/ref/doctree.html
 
 #[macro_use]
 mod macro_util;
@@ -33,20 +34,22 @@ mod tests {
         title.append_child(image);
         doc.append_child(title);
 
-        println!("{:?}", doc);
+        println!("{doc:?}");
     }
 
     #[test]
     fn descriptive() {
-        let doc = Document::with_children(vec![Title::with_children(vec![
-            "Hi".into(),
-            ImageInline::with_extra(extra_attributes::ImageInline::new(
-                "https://example.com/image.jpg".parse().unwrap(),
-            ))
+        let doc = Document::with_children(vec![
+            Title::with_children(vec![
+                "Hi".into(),
+                ImageInline::with_extra(extra_attributes::ImageInline::new(
+                    "https://example.com/image.jpg".parse().unwrap(),
+                ))
+                .into(),
+            ])
             .into(),
-        ])
-        .into()]);
+        ]);
 
-        println!("{:?}", doc);
+        println!("{doc:?}");
     }
 }
